@@ -9,6 +9,7 @@ import unittest
 import subprocess
 import tempfile
 import contextlib
+from distutils.spawn import find_executable
 
 is_py3k = sys.version_info[0] >= 3
 BITS = tuple.__itemsize__ * 8
@@ -31,7 +32,6 @@ import llvmpy
 
 tests = []
 
-
 # ---------------------------------------------------------------------------
 
 if sys.version_info[:2] <= (2, 6):
@@ -674,6 +674,7 @@ tests.append(TestTargetMachines)
 # ---------------------------------------------------------------------------
 
 class TestNative(TestCase):
+
     def setUp(self):
         self.tmpdir = tempfile.mkdtemp()
 
@@ -694,8 +695,12 @@ class TestNative(TestCase):
         return m
 
     def _compile(self, src):
+        cc = find_executable('cc')
+        if not cc:
+            return
+
         dst = os.path.join(self.tmpdir, 'llvmobj.out')
-        s = subprocess.call(['cc', '-o', dst, src])
+        s = subprocess.call([cc, '-o', dst, src])
         if s != 0:
             raise Exception("Cannot compile")
 
@@ -1240,6 +1245,18 @@ class TestNamedMetaData(TestCase):
 
 tests.append(TestNamedMetaData)
 
+
+# ---------------------------------------------------------------------------
+
+class TestStruct(TestCase):
+    def test_struct_identical(self):
+        m = Module.new('test_struct_identical')
+        ta = Type.struct([Type.int(32), Type.float()], name='ta')
+        tb = Type.struct([Type.int(32), Type.float()])
+        self.assertTrue(ta.is_layout_identical(tb))
+
+tests.append(TestStruct)
+
 # ---------------------------------------------------------------------------
 
 def run(verbosity=1):
